# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-19 12:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0014_remove_userprofile_is_leave'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userleaverecord',
            options={'ordering': ['-created_at'], 'permissions': (('update_type_cancel', '\u53ef\u4ee5\u9500\u5047'), ('change_check', '\u53ef\u4ee5\u5ba1\u6838\u7528\u6237\u7684\u8bf7\u5047'))},
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'
from django.conf.urls import include, url
from django.contrib.auth import views as auth_views

from . import views

app_name = "bee_django_user"

urlpatterns = [
    url(r'^test/$', views.test, name='test'),
    url(r'^$', views.UserList.as_view(), name='index'),

    url(r'^login/$', auth_views.LoginView.as_view(template_name='bee_django_user/user/login.html'), name='user_login'),
    url(r'^logout/$', auth_views.logout, {'next_page': '/user/login'}, name='user_logout'),
    url(r'^password/change/$', views.UserPasswordChangeView.as_view(), name='user_password_change'),
    url(r'^password/change/done/$', auth_views.PasswordChangeDoneView.as_view(
        template_name='bee_django_user/user/password_change_done.html'
    ), name='user_password_change_done'),
    url(r'^password/reset/(?P<pk>[0-9]+)/$', views.UserPasswordResetView.as_view(), name='user_password_reset'),

    # 学生
    url(r'^list/$', views.UserList.as_view(), name='user_list'),
    url(r'^detail/(?P<pk>[0-9]+)/$', views.UserDetail.as_view(), name='user_detail'),
    url(r'^create/$', views.UserCreate.as_view(), name='user_create'),
    url(r'^code/create/$', views.CodeUserCreate.as_view(), name='code_user_create'),
    url(r'^update/(?P<pk>[0-9]+)/$', views.UserUpdate.as_view(), name='user_update'),
    url(r'^group/update/(?P<pk>[0-9]+)/$', views.UserGroupUpdate.as_view(), name='user_group_update'),
    url(r'^sn/update/(?P<pk>[0-9]+)/$', views.UserSNUpdate.as_view(), name='user_sn_update'),
    # 组及权限
    url(r'^group/list/$', views.GroupList.as_view(), name='group_list'),
    url(r'^status/save/$', views.StatusSave.as_view(), name='status_save'),

    # 结课日期
    url(r'^leave/list/(?P<user_id>[0-9]+)/$', views.LeaveList.as_view(), name='leave_list'),
    url(r'^leave/detail/(?P<pk>[0-9]+)/$', views.LeaveDetail.as_view(), name='leave_detail'),
    url(r'^leave/add/(?P<user_id>[0-9]+)/$', views.LeaveCreate.as_view(), name='leave_add'),
    url(r'^leave/check/$', views.LeaveUpdateCheck.as_view(), name='leave_check'),
    url(r'^leave/cancel/(?P<pk>[0-9]+)/$', views.LeaveCancel.as_view(), name='leave_cancel'),
    url(r'^leave/delete/(?P<pk>[0-9]+)/$', views.LeaveDelete.as_view(), name='leave_delete'),

    # 班级
    url(r'^class/list/$', views.ClassList.as_view(), name='class_list'),
    url(r'^class/create/$', views.ClassCreate.as_view(), name='class_create'),
    url(r'^class/detail/(?P<pk>[0-9]+)/$', views.ClassDetail.as_view(), name='class_detail'),
    url(r'^class/update/(?P<pk>[0-9]+)/$', views.ClassUpdate.as_view(), name='class_update'),

]



# -*- coding:utf-8 -*-
__author__ = 'bee'
from django.dispatch import Signal

# 费用审核后的信号
update_user_expire_signal = Signal(providing_args=["leave_record"])

# 禁用/暂停/恢复用户的信号
update_user_active_pause_signal = Signal(providing_args=["user","active","pause"])

create_user_signal = Signal(providing_args=["user"])


# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-26 09:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0006_userleaverecord'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userleaverecord',
            name='old_expire',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u539f\u7ed3\u8bfe\u65e5\u671f'),
        ),
        migrations.AlterField(
            model_name='userleaverecord',
            name='type',
            field=models.IntegerField(choices=[(1, '\u8bf7\u5047'), (2, '\u9500\u5047'), (3, '\u5ef6\u671f')], default=1, verbose_name='\u7c7b\u578b'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-02-19 14:13
from __future__ import unicode_literals

from django.db import migrations
import imagekit.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0015_auto_20181219_2057'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='avatar',
            field=imagekit.models.fields.ProcessedImageField(blank=True, default='avatars/default.jpg', null=True, upload_to='avatars', verbose_name='\u5934\u50cf'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-17 08:41
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0002_auto_20180516_1834'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userclass',
            options={'ordering': ['-created_at'], 'permissions': (('view_all_classes', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u73ed\u7ea7'), ('view_manage_classes', '\u53ef\u4ee5\u67e5\u770b\u7ba1\u7406\u7684\u73ed\u7ea7'), ('view_teach_classes', '\u53ef\u4ee5\u67e5\u770b\u6559\u7684\u73ed\u7ea7'))},
        ),
        migrations.AlterModelOptions(
            name='userprofile',
            options={'ordering': ['-created_at'], 'permissions': (('can_manage', '\u53ef\u4ee5\u8bbf\u95ee\u540e\u53f0\u7ba1\u7406'), ('can_change_user_group', '\u53ef\u4ee5\u4fee\u6539\u7528\u6237\u7ec4'), ('view_all_users', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u7528\u6237'), ('view_manage_users', '\u53ef\u4ee5\u67e5\u770b\u7ba1\u7406\u7684\u7528\u6237'), ('view_teach_users', '\u53ef\u4ee5\u67e5\u770b\u6559\u7684\u7528\u6237'))},
        ),
    ]
